@@ -26,6 +26,8 @@ is coming from.
 from ._extras import *
 
 EXTRA_NAMES = [
+    'bbytes',
+    'bbytearray',
     'first',
     'inverted',
     'last',
@@ -42,6 +44,8 @@ def upgrade_builtins():
     
     Additional plib-specific "builtins":
     
+    - ``bbytes``
+    - ``bbytearray``
     - ``first``
     - ``inverted``
     - ``last``
